"use strict";

import React, { useState, useEffect } from 'react';
import { Image as RNImage } from 'react-native';

/**
 * An image asset that has to be loaded from a URI
 */

/**
 * An image asset that is loaded from a require('path/to/file') call
 */

/**
 * A source for the image loader
 */

/**
 * Fallback image asset(s)
 */
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * A barebones image loader component that can handle falling back to backup images when the primary image fails to load
 */
const Image = props => {
  const {
    // After spending a few hours trying to get this to work, I'm giving up
    // As a workaround, I'm casting the `Image` component to `any`
    // TODO: Fix this typing
    component: CustomComponent = RNImage,
    source,
    fallback,
    onError,
    ...rest
  } = props;
  const [currentSource, setCurrentSource] = useState(source);
  const [sourceIndex, setSourceIndex] = useState(0);

  // Start with the source prop
  // And reset the index when the source or fallback changes
  useEffect(() => {
    setCurrentSource(source);
    setSourceIndex(0);
  }, [source, fallback]);
  const handleError = error => {
    // If we have more sources to try, move to the next one
    const nextIndex = sourceIndex + 1;

    // The logic can never go back to the source prop on an onError event
    // It can only move forward to a fallback
    // So, we can safely assume that the nextIndex will always be greater than 0
    // We are using this logic to resolve the next fallback source
    const fallbacks = Array.isArray(fallback) ? fallback : [fallback];
    const nextSource = fallbacks[nextIndex - 1]; // Subtracting 1 to compensate for the source item

    if (nextSource) {
      setSourceIndex(nextIndex);
      setCurrentSource(nextSource);
    } else {
      // The sources have been exhausted
      // Call the onError callback if provided
      onError?.(error);
    }
  };
  return /*#__PURE__*/_jsx(CustomComponent, {
    source: currentSource,
    onError: handleError,
    ...rest
  });
};
export default Image;
//# sourceMappingURL=Image.js.map